Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_7_1_sq
   :fromid: mucp_7_1, mucp_7_1_ac_q
   :toggle:

.. selectquestion:: mucp_7_2_sq
   :fromid: mucp_7_2, mucp_7_2_ac_q
   :toggle:

.. selectquestion:: mucp_7_3_sq
   :fromid: mucp_7_3, mucp_7_3_ac_q
   :toggle:

.. selectquestion:: mucp_7_4_sq
   :fromid: mucp_7_4, mucp_7_4_ac_q
   :toggle:

.. selectquestion:: mucp_7_5_sq
   :fromid: mucp_7_5, mucp_7_5_ac_q
   :toggle:

.. selectquestion:: mucp_7_6_sq
   :fromid: mucp_7_6, mucp_7_6_ac_q
   :toggle:

.. selectquestion:: mucp_7_7_sq
   :fromid: mucp_7_7, mucp_7_7_ac_q
   :toggle:

.. selectquestion:: mucp_7_8_sq
   :fromid: mucp_7_8, mucp_7_8_ac_q
   :toggle:

.. selectquestion:: mucp_7_9_sq
   :fromid: mucp_7_9, mucp_7_9_ac_q
   :toggle:

.. selectquestion:: mucp_7_10_sq
   :fromid: mucp_7_10, mucp_7_10_ac_q
   :toggle:

.. selectquestion:: mucp_7_11_sq
   :fromid: mucp_7_11, mucp_7_11_ac_q
   :toggle:
